@@ -102,7 +102,7 @@ NULL
 #'   )
 #' }
 #'
-#' # create problem with maximum utility objective
+#' # create problem with maximum cover objective
 #' p1 <-
 #'   problem(sim_pu_raster, sim_binary_features) %>%
 #'   add_max_cover_objective(500) %>%
@@ -117,7 +117,7 @@ NULL
 #'
 #' # threshold the multi-zone feature data to generate binary biodiversity data
 #' sim_binary_features_zones <- sim_zones_features
-#' for (z in number_of_zones(sim_zones_features)) {
+#' for (z in seq_len(number_of_zones(sim_zones_features))) {
 #'   thresholds <- terra::global(
 #'     sim_zones_features[[z]], fun = quantile, probs = 0.5, na.rm = TRUE
 #'   )
@@ -128,7 +128,7 @@ NULL
 #'   }
 #' }
 #'
-#' # create multi-zone problem with maximum utility objective that
+#' # create multi-zone problem with maximum cover objective that
 #' # has a single budget for all zones
 #' p2 <-
 #'   problem(sim_zones_pu_raster, sim_binary_features_zones) %>%
@@ -142,7 +142,7 @@ NULL
 #' # plot solution
 #' plot(category_layer(s2), main = "solution", axes = FALSE)
 #'
-#' # create multi-zone problem with maximum utility objective that
+#' # create multi-zone problem with maximum cover objective that
 #' # has separate budgets for each zone
 #' p3 <-
 #'   problem(sim_zones_pu_raster, sim_binary_features_zones) %>%
@@ -163,8 +163,8 @@ NULL
 #' @export
 add_max_cover_objective <- function(x, budget) {
   # assert argument is valid
-  rlang::check_required(x)
-  rlang::check_required(budget)
+  assert_required(x)
+  assert_required(budget)
   assert(
     is_conservation_problem(x),
     is.numeric(budget),
