@@ -123,8 +123,8 @@ NULL
 #' @export
 add_max_utility_objective <- function(x, budget) {
   # assert argument is valid
-  rlang::check_required(x)
-  rlang::check_required(budget)
+  assert_required(x)
+  assert_required(budget)
   assert(
     is_conservation_problem(x),
     is.numeric(budget),
