@@ -140,7 +140,9 @@ methods::setMethod(
     # assert arguments are valid
     assert(
       inherits(x, "SpatRaster"),
+      is_numeric_values(x),
       inherits(y, "SpatRaster"),
+      is_numeric_values(y),
       terra::nlyr(x) == 1,
       is_same_crs(x, y),
       is_comparable_raster(x, y)
@@ -200,6 +202,7 @@ methods::setMethod(
     # assert arguments are valid
     assert(
       inherits(x, "SpatRaster"),
+      is_numeric_values(x),
       inherits(y, "sf"),
       terra::nlyr(x) == 1,
       is_same_crs(x, y),
@@ -225,6 +228,7 @@ methods::setMethod("intersecting_units",
     assert(
       inherits(x, "sf"),
       inherits(y, "SpatRaster"),
+      is_numeric_values(y),
       terra::nlyr(y) == 1,
       is_same_crs(x, y),
       is_spatial_extents_overlap(x, y)
