@@ -16,44 +16,47 @@ assertthat::on_failure(is_numeric_values)  <- function(call, env) {
   paste(deparse(call$x), "has non-numeric values")
 }
 
+#' @export
 is_numeric_values.default <- function(x) {
   FALSE
 }
 
-.S3method("is_numeric_values", "default", is_numeric_values.default)
-
+#' @export
 is_numeric_values.numeric <- function(x) {
   is.numeric(x)
 }
 
-.S3method("is_numeric_values", "numeric", is_numeric_values.numeric)
-
+#' @export
 is_numeric_values.Matrix <- function(x) {
   is.numeric(x@x)
 }
 
-.S3method("is_numeric_values", "Matrix", is_numeric_values.Matrix)
-
+#' @export
 is_numeric_values.matrix <- function(x) {
   is.numeric(c(x))
 }
 
-.S3method("is_numeric_values", "matrix", is_numeric_values.matrix)
-
+#' @export
 is_numeric_values.data.frame <- function(x) {
   all(vapply(x, is_numeric_values, logical(1)))
 }
 
-.S3method("is_numeric_values", "data.frame", is_numeric_values.data.frame)
-
+#' @export
 is_numeric_values.Spatial <- function(x) {
   all(vapply(x@data, is_numeric_values, logical(1)))
 }
 
-.S3method("is_numeric_values", "Spatial", is_numeric_values.Spatial)
-
+#' @export
 is_numeric_values.sf <- function(x) {
   all(vapply(sf::st_drop_geometry(x), is_numeric_values, logical(1)))
 }
 
-.S3method("is_numeric_values", "sf", is_numeric_values.sf)
+#' @export
+is_numeric_values.SpatRaster <- function(x) {
+  all(!terra::is.factor(x))
+}
+
+#' @export
+is_numeric_values.Raster <- function(x) {
+  TRUE
+}
