@@ -83,11 +83,11 @@ NULL
 #' @export
 loglinear_interpolation <- function(x, coordinate_one_x, coordinate_one_y,
                                     coordinate_two_x, coordinate_two_y) {
-  rlang::check_required(x)
-  rlang::check_required(coordinate_one_x)
-  rlang::check_required(coordinate_one_y)
-  rlang::check_required(coordinate_two_x)
-  rlang::check_required(coordinate_two_y)
+  assert_required(x)
+  assert_required(coordinate_one_x)
+  assert_required(coordinate_one_y)
+  assert_required(coordinate_two_x)
+  assert_required(coordinate_two_y)
   assert(
     is.numeric(x),
     all_finite(x),
