@@ -39,11 +39,4 @@ void import_connectivity_matrix_list(
   bool
 );
 
-// wrapper around R's RNG so that users can use set.seed() in R
-// console to make analyses reproducible
-// obtained from here: http://gallery.rcpp.org/articles/stl-random-shuffle/
-inline int rand_wrapper(const int n) { return floor(unif_rand()*n); }
-
-void r_random_shuffle(std::vector<std::size_t>&);
-
 #endif
