@@ -1,5 +1,3 @@
-context("problem (deprecated)")
-
 test_that("x = RasterLayer, features = RasterStack", {
   # import data
   sim_pu_raster <- get_sim_pu_raster()
@@ -28,19 +26,21 @@ test_that("x = RasterLayer, features = RasterStack", {
   )
   expect_equal(problem(sim_pu_raster, sim_pu_raster)$number_of_features(), 1L)
   # tests for planning_unit_costs field
-  expect_equivalent(
+  expect_equal(
     x$planning_unit_costs(),
-    matrix(sim_pu_raster[[1]][!is.na(sim_pu_raster)], ncol = 1)
+    matrix(sim_pu_raster[[1]][!is.na(sim_pu_raster)], ncol = 1),
+    ignore_attr = TRUE
   )
   expect_equal(colnames(x$planning_unit_costs()), names(sim_pu_raster))
   # tests for feature_abundances_in_planning_units field
-  expect_equivalent(
+  expect_equal(
     x$feature_abundances_in_planning_units(),
     matrix(
       terra::global(
         terra::mask(sim_features, sim_pu_raster), "sum", na.rm = TRUE
       )[[1]],
-    )
+    ),
+    ignore_attr = TRUE
   )
   expect_equal(
     colnames(x$feature_abundances_in_planning_units()),
@@ -51,9 +51,10 @@ test_that("x = RasterLayer, features = RasterStack", {
     x$feature_names()
   )
   # tests for feature_abundances_in_total_units field
-  expect_equivalent(
+  expect_equal(
     x$feature_abundances_in_total_units(),
-    matrix(terra::global(sim_features, "sum", na.rm = TRUE)[[1]], ncol = 1)
+    matrix(terra::global(sim_features, "sum", na.rm = TRUE)[[1]], ncol = 1),
+    ignore_attr = TRUE
   )
   expect_equal(
     colnames(x$feature_abundances_in_total_units()),
@@ -64,9 +65,10 @@ test_that("x = RasterLayer, features = RasterStack", {
     x$feature_names()
   )
   # tests for rij_matrix field
-  expect_equivalent(
+  expect_equal(
     x$data$rij_matrix,
-    list(rij_matrix(sim_pu_raster, sim_features))
+    list(rij_matrix(sim_pu_raster, sim_features)),
+    ignore_attr = TRUE
   )
   expect_equal(names(x$data$rij_matrix), x$zone_names())
   expect_equal(rownames(x$data$rij_matrix[[1]]), x$feature_names())
@@ -78,6 +80,7 @@ test_that("x = RasterStack, features = ZonesRaster", {
   # import data
   sim_zones_pu_raster <- get_sim_zones_pu_raster()
   sim_zones_features <- get_sim_zones_features()
+  sim_units_mask <- max(!is.na(sim_zones_pu_raster))
   # create problem
   expect_warning(
     x <- problem(
@@ -103,23 +106,25 @@ test_that("x = RasterStack, features = ZonesRaster", {
   )
   expect_equal(x$number_of_total_units(), terra::ncell(sim_zones_pu_raster))
   # tests for planning_unit_costs field
-  expect_equivalent(
+  expect_equal(
     x$planning_unit_costs(),
-    sim_zones_pu_raster[min(is.na(sim_zones_pu_raster)) == 0]
+    sim_zones_pu_raster[min(is.na(sim_zones_pu_raster)) == 0],
+    ignore_attr = TRUE
   )
   expect_equal(
     colnames(x$planning_unit_costs()),
     zone_names(sim_zones_features)
   )
   # tests for feature_abundances_in_planning_units field
-  expect_equivalent(
+  expect_equal(
     x$feature_abundances_in_planning_units(),
     sapply(seq_len(terra::nlyr(sim_zones_pu_raster)), function(i) {
       terra::global(
         terra::mask(sim_zones_features[[i]], sim_zones_pu_raster[[i]]),
         "sum", na.rm = TRUE
       )[[1]]
-    })
+    }),
+    ignore_attr = TRUE
   )
   expect_equal(
     colnames(x$feature_abundances_in_planning_units()),
@@ -130,11 +135,12 @@ test_that("x = RasterStack, features = ZonesRaster", {
     feature_names(sim_zones_features)
   )
   # tests for feature_abundances_in_total_units field
-  expect_equivalent(
+  expect_equal(
     x$feature_abundances_in_total_units(),
     sapply(seq_len(terra::nlyr(sim_zones_pu_raster)), function(i) {
       terra::global(sim_zones_features[[i]], "sum", na.rm = TRUE)[[1]]
-    })
+    }),
+    ignore_attr = TRUE
   )
   expect_equal(
     colnames(x$feature_abundances_in_total_units()),
@@ -145,22 +151,29 @@ test_that("x = RasterStack, features = ZonesRaster", {
     feature_names(sim_zones_features)
   )
   # tests for rij_matrix field
-  expect_equivalent(
+  expect_equal(
     x$data$rij_matrix,
     lapply(
       seq_len(terra::nlyr(sim_zones_pu_raster)), function(i) {
-        rij_matrix(sim_zones_pu_raster[[i]], sim_zones_features[[i]])
+        l <- sim_zones_pu_raster[[i]]
+        l <- terra::mask(l, sim_units_mask, maskvalues = 0)
+        l[which(is.na(terra::values(l)[x$planning_unit_indices()]))] <- 0
+        m <- rij_matrix(l, sim_zones_features[[i]])
+        rownames(m) <- x$feature_names()
+        m
       }
-    )
+    ),
+    ignore_attr = TRUE
   )
   expect_equal(names(x$data$rij_matrix), zone_names(sim_zones_features))
-  expect_equivalent(
+  expect_equal(
     sapply(x$data$rij_matrix, rownames),
     matrix(
       feature_names(sim_zones_features),
       ncol = number_of_zones(sim_zones_features),
       nrow = number_of_features(sim_zones_features)
-    )
+    ),
+    ignore_attr = TRUE
   )
   # test that calling targets before they have been initialized throws error
   expect_error(x$feature_targets())
@@ -173,11 +186,13 @@ test_that("x = Spatial, features = RasterStack", {
   # update data
   sim_pu_polygons$cost[1:5] <- NA
   # create problem
-  expect_warning(
-    x <- problem(
-      sf::as_Spatial(sim_pu_polygons), raster::stack(sim_features), "cost"
-    ),
-    "deprecated"
+  suppressWarnings(
+    expect_warning(
+      x <- problem(
+        sf::as_Spatial(sim_pu_polygons), raster::stack(sim_features), "cost"
+      ),
+      "deprecated"
+    )
   )
   # verify that object can be printed
   suppressMessages(print(x))
@@ -190,15 +205,17 @@ test_that("x = Spatial, features = RasterStack", {
   expect_equal(x$planning_unit_indices(), which(!is.na(sim_pu_polygons$cost)))
   expect_equal(x$number_of_total_units(), nrow(sim_pu_polygons))
   # tests for planning_unit_costs field
-  expect_equivalent(
+  expect_equal(
     x$planning_unit_costs(),
-    matrix(sim_pu_polygons$cost[!is.na(sim_pu_polygons$cost)], ncol = 1)
+    matrix(sim_pu_polygons$cost[!is.na(sim_pu_polygons$cost)], ncol = 1),
+    ignore_attr = TRUE
   )
   expect_equal(colnames(x$planning_unit_costs()), "cost")
   # tests for feature_abundances_in_planning_units field
-  expect_equivalent(
+  expect_equal(
     x$feature_abundances_in_planning_units(),
-    Matrix::rowSums(x$data$rij_matrix[[1]])
+    Matrix::rowSums(x$data$rij_matrix[[1]]),
+    ignore_attr = TRUE
   )
   expect_equal(
     colnames(x$feature_abundances_in_planning_units()),
@@ -209,7 +226,7 @@ test_that("x = Spatial, features = RasterStack", {
     names(sim_features)
   )
   # tests for feature_abundances_in_total_units field
-  expect_equivalent(
+  expect_equal(
     x$feature_abundances_in_total_units(),
     matrix(
       colSums(
@@ -219,7 +236,8 @@ test_that("x = Spatial, features = RasterStack", {
         )
       ),
       ncol = 1
-    )
+    ),
+    ignore_attr = TRUE
   )
   expect_equal(
     colnames(x$feature_abundances_in_total_units()),
@@ -230,14 +248,15 @@ test_that("x = Spatial, features = RasterStack", {
     names(sim_features)
   )
   # tests for rij_matrix field
-  expect_equivalent(
+  expect_equal(
     x$data$rij_matrix,
     list(
       rij_matrix(
         sim_pu_polygons[!is.na(sim_pu_polygons[[1]]), ],
         sim_features
       )
-    )
+    ),
+    ignore_attr = TRUE
   )
   expect_equal(names(x$data$rij_matrix), "cost")
   expect_equal(rownames(x$data$rij_matrix[[1]]), names(sim_features))
@@ -253,12 +272,15 @@ test_that("x = Spatial, features = ZonesRaster", {
   sim_zones_pu_polygons[5, paste0("cost_", 1:3)] <- NA
   sim_zones_pu_polygons[4, "cost_1"] <- NA
   # create problem
-  expect_warning(
-    x <- problem(
-      sf::as_Spatial(sim_zones_pu_polygons), as.ZonesRaster(sim_zones_features),
-      paste0("cost_", 1:3)
-    ),
-    "deprecated"
+  suppressWarnings(
+    expect_warning(
+      x <- problem(
+        sf::as_Spatial(sim_zones_pu_polygons),
+        as.ZonesRaster(sim_zones_features),
+        paste0("cost_", 1:3)
+      ),
+      "deprecated"
+    )
   )
   # verify that object can be printed
   suppressMessages(print(x))
@@ -274,25 +296,27 @@ test_that("x = Spatial, features = ZonesRaster", {
   )
   expect_equal(x$number_of_total_units(), nrow(sim_zones_pu_polygons))
   # tests for planning_unit_costs field
-  expect_equivalent(
+  expect_equal(
     x$planning_unit_costs(),
     as.matrix(
       sf::st_drop_geometry(sim_zones_pu_polygons)[-5, paste0("cost_", 1:3)]
-    )
+    ),
+    ignore_attr = TRUE
   )
   expect_equal(
     colnames(x$planning_unit_costs()),
     zone_names(sim_zones_features)
   )
   # tests for feature_abundances_in_planning_units field
-  expect_equivalent(
+  expect_equal(
     x$feature_abundances_in_planning_units(),
     sapply(seq_along(x$data$rij_matrix), function(i) {
       pos1 <- x$planning_unit_indices()
       pos2 <- which(!is.na(sim_zones_pu_polygons[[paste0("cost_", i)]]))
       pos3 <- match(pos2, pos1)
       Matrix::rowSums(x$data$rij_matrix[[i]][, pos3, drop = FALSE])
-    })
+    }),
+    ignore_attr = TRUE
   )
   expect_equal(
     colnames(x$feature_abundances_in_planning_units()),
@@ -303,7 +327,7 @@ test_that("x = Spatial, features = ZonesRaster", {
     feature_names(sim_zones_features)
   )
   # tests for feature_abundances_in_total_units field
-  expect_equivalent(
+  expect_equal(
     x$feature_abundances_in_total_units(),
     sapply(
       lapply(
@@ -312,7 +336,8 @@ test_that("x = Spatial, features = ZonesRaster", {
       ),
       colSums,
       na.rm = TRUE
-    )
+    ),
+    ignore_attr = TRUE
   )
   expect_equal(
     colnames(x$feature_abundances_in_total_units()),
@@ -323,18 +348,24 @@ test_that("x = Spatial, features = ZonesRaster", {
     feature_names(sim_zones_features)
   )
   # tests for rij_matrix field
-  expect_equivalent(
+  expect_equal(
     x$data$rij_matrix,
-    lapply(sim_zones_features, rij_matrix, x = sim_zones_pu_polygons[-5, ])
+    lapply(sim_zones_features, function(l) {
+      m <- rij_matrix(x = sim_zones_pu_polygons[-5, ], y = l)
+      rownames(m) <- x$feature_names()
+      m
+    }),
+    ignore_attr = TRUE
   )
   expect_equal(names(x$data$rij_matrix), zone_names(sim_zones_features))
-  expect_equivalent(
+  expect_equal(
     sapply(x$data$rij_matrix, rownames),
     matrix(
       feature_names(sim_zones_features),
       ncol = number_of_zones(sim_zones_features),
       nrow = number_of_features(sim_zones_features)
-    )
+    ),
+    ignore_attr = TRUE
   )
   # test that calling targets before they have been initialized throws error
   expect_error(x$feature_targets())
@@ -364,13 +395,14 @@ test_that("x = Spatial, features = character", {
   expect_equal(x$planning_unit_indices(), c(1, seq(3, nrow(sim_pu_polygons))))
   expect_equal(x$number_of_total_units(), nrow(sim_pu_polygons))
   # tests for planning_unit_costs field
-  expect_equivalent(
+  expect_equal(
     x$planning_unit_costs(),
-    matrix(sim_pu_polygons$cost[-2], ncol = 1)
+    matrix(sim_pu_polygons$cost[-2], ncol = 1),
+    ignore_attr = TRUE
   )
   expect_equal(colnames(x$planning_unit_costs()), "cost")
   # tests for feature_abundances_in_planning_units field
-  expect_equivalent(
+  expect_equal(
     x$feature_abundances_in_planning_units(),
     matrix(
       colSums(
@@ -378,7 +410,8 @@ test_that("x = Spatial, features = character", {
         na.rm = TRUE
       ),
       ncol = 1
-    )
+    ),
+    ignore_attr = TRUE
   )
   expect_equal(
     colnames(x$feature_abundances_in_planning_units()),
@@ -389,7 +422,7 @@ test_that("x = Spatial, features = character", {
     c("spp1", "spp2")
   )
   # tests for feature_abundances_in_total_units field
-  expect_equivalent(
+  expect_equal(
     x$feature_abundances_in_total_units(),
     matrix(
       colSums(
@@ -397,7 +430,8 @@ test_that("x = Spatial, features = character", {
         na.rm = TRUE
       ),
       ncol = 1
-    )
+    ),
+    ignore_attr = TRUE
   )
   expect_equal(
     colnames(x$feature_abundances_in_total_units()),
@@ -471,15 +505,16 @@ test_that("x = Spatial, features = ZonesCharacter", {
   )
   expect_equal(x$number_of_total_units(), nrow(sim_zones_pu_polygons))
   # tests for planning_unit_costs field
-  expect_equivalent(
+  expect_equal(
     x$planning_unit_costs(),
     as.matrix(
       sf::st_drop_geometry(sim_zones_pu_polygons)[-3, c("cost_1", "cost_2")]
-    )
+    ),
+    ignore_attr = TRUE
   )
   expect_equal(colnames(x$planning_unit_costs()), c("z1", "z2"))
   # tests for feature_abundances_in_planning_units field
-  expect_equivalent(
+  expect_equal(
     x$feature_abundances_in_planning_units(),
     matrix(
       c(
@@ -500,8 +535,10 @@ test_that("x = Spatial, features = ZonesCharacter", {
           na.rm = TRUE
         )
       ),
-      ncol = 4
-    )
+      ncol = 2,
+      dimnames = list(x$feature_names(), x$zone_names())
+    ),
+    ignore_attr = TRUE
   )
   expect_equal(
     colnames(x$feature_abundances_in_planning_units()),
@@ -512,7 +549,7 @@ test_that("x = Spatial, features = ZonesCharacter", {
     c("spp1", "spp2")
   )
   # tests for feature_abundances_in_total_units field
-  expect_equivalent(
+  expect_equal(
     x$feature_abundances_in_total_units(),
     matrix(
       colSums(
@@ -522,7 +559,8 @@ test_that("x = Spatial, features = ZonesCharacter", {
         na.rm = TRUE
       ),
       ncol = 2
-    )
+    ),
+    ignore_attr = TRUE
   )
   expect_equal(
     colnames(x$feature_abundances_in_total_units()),
@@ -591,15 +629,17 @@ test_that("x = sf, features = RasterStack", {
   expect_equal(x$planning_unit_indices(), which(!is.na(sim_pu_polygons$cost)))
   expect_equal(x$number_of_total_units(), nrow(sim_pu_polygons))
   # tests for planning_unit_costs field
-  expect_equivalent(
+  expect_equal(
     x$planning_unit_costs(),
-    matrix(sim_pu_polygons$cost[!is.na(sim_pu_polygons$cost)], ncol = 1)
+    matrix(sim_pu_polygons$cost[!is.na(sim_pu_polygons$cost)], ncol = 1),
+    ignore_attr = TRUE
   )
   expect_equal(colnames(x$planning_unit_costs()), "cost")
   # tests for feature_abundances_in_planning_units field
-  expect_equivalent(
+  expect_equal(
     x$feature_abundances_in_planning_units(),
-    Matrix::rowSums(x$data$rij_matrix[[1]])
+    Matrix::rowSums(x$data$rij_matrix[[1]]),
+    ignore_attr = TRUE
   )
   expect_equal(
     colnames(x$feature_abundances_in_planning_units()),
@@ -610,7 +650,7 @@ test_that("x = sf, features = RasterStack", {
     names(sim_features)
   )
   # tests for feature_abundances_in_total_units field
-  expect_equivalent(
+  expect_equal(
     x$feature_abundances_in_total_units(),
     matrix(
       colSums(
@@ -618,7 +658,8 @@ test_that("x = sf, features = RasterStack", {
           sim_features, sim_pu_polygons, "sum", ID = FALSE, na.rm = TRUE)
         ),
       ncol = 1
-    )
+    ),
+    ignore_attr = TRUE
   )
   expect_equal(
     colnames(x$feature_abundances_in_total_units()),
@@ -629,14 +670,15 @@ test_that("x = sf, features = RasterStack", {
     names(sim_features)
   )
   # tests for rij_matrix field
-  expect_equivalent(
+  expect_equal(
     x$data$rij_matrix,
     list(
       rij_matrix(
         sim_pu_polygons[!is.na(sim_pu_polygons[[1]]), ],
         sim_features
       )
-    )
+    ),
+    ignore_attr = TRUE
   )
   expect_equal(names(x$data$rij_matrix), "cost")
   expect_equal(rownames(x$data$rij_matrix[[1]]), names(sim_features))
@@ -672,18 +714,19 @@ test_that("x = sf, features = ZonesRaster", {
   )
   expect_equal(x$number_of_total_units(), nrow(sim_zones_pu_polygons))
   # tests for planning_unit_costs field
-  expect_equivalent(
+  expect_equal(
     x$planning_unit_costs(),
     as.matrix(
       sf::st_drop_geometry(sim_zones_pu_polygons)[-5, paste0("cost_", 1:3)]
-    )
+    ),
+    ignore_attr = TRUE
   )
   expect_equal(
     colnames(x$planning_unit_costs()),
     zone_names(sim_zones_features)
   )
   # tests for feature_abundances_in_planning_units field
-  expect_equivalent(
+  expect_equal(
     x$feature_abundances_in_planning_units(),
     sapply(seq_along(x$data$rij_matrix), function(i) {
       pos1 <- x$planning_unit_indices()
@@ -694,7 +737,8 @@ test_that("x = sf, features = ZonesRaster", {
       )
       pos3 <- match(pos2, pos1)
       Matrix::rowSums(x$data$rij_matrix[[i]][, pos3, drop = FALSE])
-    })
+    }),
+    ignore_attr = TRUE
   )
   expect_equal(
     colnames(x$feature_abundances_in_planning_units()),
@@ -705,7 +749,7 @@ test_that("x = sf, features = ZonesRaster", {
     feature_names(sim_zones_features)
   )
   # tests for feature_abundances_in_total_units field
-  expect_equivalent(
+  expect_equal(
     x$feature_abundances_in_total_units(),
     sapply(
       lapply(
@@ -714,7 +758,8 @@ test_that("x = sf, features = ZonesRaster", {
       ),
       colSums,
       na.rm = TRUE
-    )
+    ),
+    ignore_attr = TRUE
   )
   expect_equal(
     colnames(x$feature_abundances_in_total_units()),
@@ -725,20 +770,26 @@ test_that("x = sf, features = ZonesRaster", {
     feature_names(sim_zones_features)
   )
   # tests for rij_matrix field
-  expect_equivalent(
+  expect_equal(
     x$data$rij_matrix,
     lapply(
-      sim_zones_features, rij_matrix, x = sim_zones_pu_polygons[-5, ]
-    )
+      sim_zones_features, function(l) {
+        m <- rij_matrix(x = sim_zones_pu_polygons[-5, ], y = l)
+        rownames(m) <- x$feature_names()
+        m
+      }
+    ),
+    ignore_attr = TRUE
   )
   expect_equal(names(x$data$rij_matrix), zone_names(sim_zones_features))
-  expect_equivalent(
+  expect_equal(
     sapply(x$data$rij_matrix, rownames),
     matrix(
       feature_names(sim_zones_features),
       ncol = number_of_zones(sim_zones_features),
       nrow = number_of_features(sim_zones_features)
-    )
+    ),
+    ignore_attr = TRUE
   )
   # test that calling targets before they have been initialized throws error
   expect_error(x$feature_targets())
